# Async storages

Async file storages for Python

![PyPI](https://img.shields.io/pypi/v/async_storages)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/alex-oleshkevich/async_storages/Lint)
![GitHub](https://img.shields.io/github/license/alex-oleshkevich/async_storages)
![Libraries.io dependency status for latest release](https://img.shields.io/librariesio/release/pypi/async_storages)
![PyPI - Downloads](https://img.shields.io/pypi/dm/async_storages)
![GitHub Release Date](https://img.shields.io/github/release-date/alex-oleshkevich/async_storages)

## Installation

Install `async_storages` using PIP or poetry:

```bash
pip install async_storages
# or
poetry add async_storages
```

## Features

- simple abstraction over local filesystem, s3, or memory driver
- S3 integration
- Spooled In-memory driver for unit tests

## Quick start

See example application in [examples/](examples/) directory of this repository.
